@@ -1,8 +1,6 @@
 <?php
 /**
- * Class to parse List Header fields (RFC 2369/2919).
- *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -10,7 +8,7 @@
  * @author   Michael Slusarz <slusarz@horde.org>
  * @category Horde
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @package  IMP
+ * @package  ListHeaders
  */
 
 /**
@@ -19,7 +17,7 @@
  * @author   Michael Slusarz <slusarz@horde.org>
  * @category Horde
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @package  IMP
+ * @package  ListHeaders
  */
 class Horde_ListHeaders extends Horde_Mail_Rfc822
 {
@@ -43,6 +41,26 @@ class Horde_ListHeaders extends Horde_Mail_Rfc822
         );
     }
 
+   /**
+    * Do any mailing list headers exist?
+    *
+    * @since 1.2.0
+    *
+    * @param Horde_Mime_Headers $ob  Headers object.
+    *
+    * @return boolean  True if any mailing list headers exist.
+    */
+    public function listHeadersExist(Horde_Mime_Headers $ob)
+    {
+        foreach (array_keys($this->headers()) as $hdr) {
+            if (isset($ob[$hdr])) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     /**
      * Parse a list header.
      *
@@ -59,11 +77,11 @@ class Horde_ListHeaders extends Horde_Mail_Rfc822
             return false;
         }
 
-        $this->_data = $value;
-        $this->_datalen = strlen($value);
+        $this->_data = strval($value);
+        $this->_datalen = strlen($this->_data);
         $this->_params['validate'] = true;
 
-        switch (strtolower($id)) {
+        switch (Horde_String::lower($id)) {
         case 'list-archive':
         case 'list-help':
         case 'list-owner':
